@@ -1,8 +1,5 @@
 #!/usr/bin/env python
-# coding=utf-8
-# flake8: noqa F402
-"""
-The standard parser used by cmd2 built-in commands is Cmd2ArgumentParser.
+"""The standard parser used by cmd2 built-in commands is Cmd2ArgumentParser.
 The following code shows how to override it with your own parser class.
 """
 
@@ -11,13 +8,11 @@ The following code shows how to override it with your own parser class.
 # with the custom parser's type.
 import argparse
 
-argparse.cmd2_parser_module = 'examples.custom_parser'
+argparse.cmd2_parser_module = 'custom_parser'
 
 # Next import from cmd2. It will import your module just before the cmd2.Cmd class file is imported
 # and therefore override the parser class it uses on its commands.
-from cmd2 import (
-    cmd2,
-)
+from cmd2 import cmd2  # noqa: E402
 
 if __name__ == '__main__':
     import sys
