@@ -1,7 +1,6 @@
-#
-# -*- coding: utf-8 -*-
-"""Development related tasks to be run with 'invoke'"""
+"""Development related tasks to be run with 'invoke'."""
 
+import contextlib
 import os
 import pathlib
 import shutil
@@ -13,20 +12,18 @@ TASK_ROOT_STR = str(TASK_ROOT)
 
 
 # shared function
-def rmrf(items, verbose=True):
-    """Silently remove a list of directories or files"""
+def rmrf(items, verbose=True) -> None:
+    """Silently remove a list of directories or files."""
     if isinstance(items, str):
         items = [items]
 
     for item in items:
         if verbose:
-            print("Removing {}".format(item))
+            print(f"Removing {item}")
         shutil.rmtree(item, ignore_errors=True)
         # rmtree doesn't remove bare files
-        try:
+        with contextlib.suppress(FileNotFoundError):
             os.remove(item)
-        except FileNotFoundError:
-            pass
 
 
 # create namespaces
@@ -42,17 +39,17 @@ namespace.add_collection(namespace_clean, 'clean')
 
 
 @invoke.task
-def pytest(context, junit=False, pty=True, append_cov=False):
-    """Run tests and code coverage using pytest"""
-    ROOT_PATH = TASK_ROOT.parent.parent
+def pytest(context, junit=False, pty=True, append_cov=False) -> None:
+    """Run tests and code coverage using pytest."""
+    root_path = TASK_ROOT.parent.parent
 
-    with context.cd(str(ROOT_PATH)):
+    with context.cd(str(root_path)):
         command_str = 'pytest --cov=cmd2_myplugin --cov-report=term --cov-report=html'
         if append_cov:
             command_str += ' --cov-append'
         if junit:
             command_str += ' --junitxml=junit/test-results.xml'
-        command_str += ' ' + str((TASK_ROOT / 'tests').relative_to(ROOT_PATH))
+        command_str += ' ' + str((TASK_ROOT / 'tests').relative_to(root_path))
         context.run(command_str, pty=pty)
 
 
@@ -60,8 +57,8 @@ namespace.add_task(pytest)
 
 
 @invoke.task
-def pytest_clean(context):
-    """Remove pytest cache and code coverage files and directories"""
+def pytest_clean(context) -> None:
+    """Remove pytest cache and code coverage files and directories."""
     # pylint: disable=unused-argument
     with context.cd(TASK_ROOT_STR):
         dirs = ['.pytest_cache', '.cache', '.coverage']
@@ -72,8 +69,8 @@ namespace_clean.add_task(pytest_clean, 'pytest')
 
 
 @invoke.task
-def pylint(context):
-    """Check code quality using pylint"""
+def pylint(context) -> None:
+    """Check code quality using pylint."""
     context.run('pylint --rcfile=cmd2_myplugin/pylintrc cmd2_myplugin')
 
 
@@ -81,8 +78,8 @@ namespace.add_task(pylint)
 
 
 @invoke.task
-def pylint_tests(context):
-    """Check code quality of test suite using pylint"""
+def pylint_tests(context) -> None:
+    """Check code quality of test suite using pylint."""
     context.run('pylint --rcfile=tests/pylintrc tests')
 
 
@@ -99,8 +96,8 @@ DISTDIR = 'dist'
 
 
 @invoke.task
-def build_clean(context):
-    """Remove the build directory"""
+def build_clean(_context) -> None:
+    """Remove the build directory."""
     # pylint: disable=unused-argument
     rmrf(BUILDDIR)
 
@@ -109,8 +106,8 @@ namespace_clean.add_task(build_clean, 'build')
 
 
 @invoke.task
-def dist_clean(context):
-    """Remove the dist directory"""
+def dist_clean(_context) -> None:
+    """Remove the dist directory."""
     # pylint: disable=unused-argument
     rmrf(DISTDIR)
 
@@ -119,8 +116,8 @@ namespace_clean.add_task(dist_clean, 'dist')
 
 
 @invoke.task
-def eggs_clean(context):
-    """Remove egg directories"""
+def eggs_clean(_context) -> None:
+    """Remove egg directories."""
     # pylint: disable=unused-argument
     dirs = set()
     dirs.add('.eggs')
@@ -136,8 +133,8 @@ namespace_clean.add_task(eggs_clean, 'eggs')
 
 
 @invoke.task
-def bytecode_clean(context):
-    """Remove __pycache__ directories and *.pyc files"""
+def bytecode_clean(_context) -> None:
+    """Remove __pycache__ directories and *.pyc files."""
     # pylint: disable=unused-argument
     dirs = set()
     for root, dirnames, files in os.walk(os.curdir):
@@ -158,33 +155,32 @@ clean_tasks = list(namespace_clean.tasks.values())
 
 
 @invoke.task(pre=list(namespace_clean.tasks.values()), default=True)
-def clean_all(context):
-    """Run all clean tasks"""
+def clean_all(context) -> None:
+    """Run all clean tasks."""
     # pylint: disable=unused-argument
-    pass
 
 
 namespace_clean.add_task(clean_all, 'all')
 
 
 @invoke.task(pre=[clean_all])
-def sdist(context):
-    """Create a source distribution"""
-    context.run('python setup.py sdist')
+def sdist(context) -> None:
+    """Create a source distribution."""
+    context.run('python -m build --sdist')
 
 
 namespace.add_task(sdist)
 
 
 @invoke.task(pre=[clean_all])
-def wheel(context):
-    """Build a wheel distribution"""
-    context.run('python setup.py bdist_wheel')
+def wheel(context) -> None:
+    """Build a wheel distribution."""
+    context.run('python -m build --wheel')
 
 
 namespace.add_task(wheel)
 
-#
+
 # these two tasks are commented out so you don't
 # accidentally run them and upload this template to pypi
 #
@@ -192,11 +188,11 @@ namespace.add_task(wheel)
 # @invoke.task(pre=[sdist, wheel])
 # def pypi(context):
 #     """Build and upload a distribution to pypi"""
-#     context.run('twine upload dist/*')
-# namespace.add_task(pypi)
+#     context.run('twine upload dist/*')  # noqa: ERA001
+# namespace.add_task(pypi)  # noqa: ERA001
 
 # @invoke.task(pre=[sdist, wheel])
 # def pypi_test(context):
-#     """Build and upload a distribution to https://test.pypi.org"""
-#     context.run('twine upload --repository-url https://test.pypi.org/legacy/ dist/*')
-# namespace.add_task(pypi_test)
+#     """Build and upload a distribution to https://test.pypi.org"""  # noqa: ERA001
+#     context.run('twine upload --repository-url https://test.pypi.org/legacy/ dist/*')  # noqa: ERA001
+# namespace.add_task(pypi_test)  # noqa: ERA001
