@@ -1,10 +1,11 @@
-# coding=utf-8
-# flake8: noqa E302
-"""
-Test plugin infrastructure and hooks.
-"""
+"""Test plugin infrastructure and hooks."""
+
 import argparse
 import sys
+from typing import NoReturn
+from unittest import (
+    mock,
+)
 
 import pytest
 
@@ -16,21 +17,15 @@ from cmd2 import (
     with_argparser,
 )
 
-# Python 3.5 had some regressions in the unitest.mock module, so use 3rd party mock if available
-try:
-    import mock
-except ImportError:
-    from unittest import mock
-
-
 
 class Plugin:
     """A mixin class for testing hook registration and calling"""
-    def __init__(self, *args, **kwargs):
+
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.reset_counters()
 
-    def reset_counters(self):
+    def reset_counters(self) -> None:
         self.called_preparse = 0
         self.called_postparsing = 0
         self.called_precmd = 0
@@ -40,7 +35,7 @@ class Plugin:
     ###
     #
     # preloop and postloop hooks
-    # which share the same signature and are thus interchangable
+    # which share the same signature and are thus interchangeable
     #
     ###
     def prepost_hook_one(self) -> None:
@@ -53,11 +48,9 @@ class Plugin:
 
     def prepost_hook_too_many_parameters(self, param) -> None:
         """A preloop or postloop hook with too many parameters"""
-        pass
 
     def prepost_hook_with_wrong_return_annotation(self) -> bool:
         """A preloop or postloop hook with incorrect return type"""
-        pass
 
     ###
     #
@@ -97,23 +90,18 @@ class Plugin:
 
     def postparse_hook_too_many_parameters(self, data1, data2) -> cmd2.plugin.PostparsingData:
         """A postparsing hook with too many parameters"""
-        pass
 
     def postparse_hook_undeclared_parameter_annotation(self, data) -> cmd2.plugin.PostparsingData:
         """A postparsing hook with an undeclared parameter type"""
-        pass
 
     def postparse_hook_wrong_parameter_annotation(self, data: str) -> cmd2.plugin.PostparsingData:
         """A postparsing hook with the wrong parameter type"""
-        pass
 
-    def postparse_hook_undeclared_return_annotation(self, data: cmd2.plugin.PostparsingData):
+    def postparse_hook_undeclared_return_annotation(self, data: cmd2.plugin.PostparsingData) -> None:
         """A postparsing hook with an undeclared return type"""
-        pass
 
     def postparse_hook_wrong_return_annotation(self, data: cmd2.plugin.PostparsingData) -> str:
         """A postparsing hook with the wrong return type"""
-        pass
 
     ###
     #
@@ -142,7 +130,6 @@ class Plugin:
 
     def precmd_hook_not_enough_parameters(self) -> plugin.PrecommandData:
         """A precommand hook with no parameters"""
-        pass
 
     def precmd_hook_too_many_parameters(self, one: plugin.PrecommandData, two: str) -> plugin.PrecommandData:
         """A precommand hook with too many parameters"""
@@ -185,7 +172,6 @@ class Plugin:
 
     def postcmd_hook_not_enough_parameters(self) -> plugin.PostcommandData:
         """A precommand hook with no parameters"""
-        pass
 
     def postcmd_hook_too_many_parameters(self, one: plugin.PostcommandData, two: str) -> plugin.PostcommandData:
         """A precommand hook with too many parameters"""
@@ -227,24 +213,34 @@ class Plugin:
         self.called_cmdfinalization += 1
         raise ValueError
 
-    def cmdfinalization_hook_system_exit(self, data: cmd2.plugin.CommandFinalizationData) -> \
-            cmd2.plugin.CommandFinalizationData:
+    def cmdfinalization_hook_system_exit(
+        self, data: cmd2.plugin.CommandFinalizationData
+    ) -> cmd2.plugin.CommandFinalizationData:
         """A command finalization hook which raises a SystemExit"""
         self.called_cmdfinalization += 1
-        raise SystemExit
+        raise SystemExit(5)
 
-    def cmdfinalization_hook_keyboard_interrupt(self, data: cmd2.plugin.CommandFinalizationData) -> \
-            cmd2.plugin.CommandFinalizationData:
+    def cmdfinalization_hook_keyboard_interrupt(
+        self, data: cmd2.plugin.CommandFinalizationData
+    ) -> cmd2.plugin.CommandFinalizationData:
         """A command finalization hook which raises a KeyboardInterrupt"""
         self.called_cmdfinalization += 1
         raise KeyboardInterrupt
 
+    def cmdfinalization_hook_passthrough_exception(
+        self, data: cmd2.plugin.CommandFinalizationData
+    ) -> cmd2.plugin.CommandFinalizationData:
+        """A command finalization hook which raises a PassThroughException"""
+        self.called_cmdfinalization += 1
+        wrapped_ex = OSError("Pass me up")
+        raise exceptions.PassThroughException(wrapped_ex=wrapped_ex)
+
     def cmdfinalization_hook_not_enough_parameters(self) -> plugin.CommandFinalizationData:
         """A command finalization hook with no parameters."""
-        pass
 
-    def cmdfinalization_hook_too_many_parameters(self, one: plugin.CommandFinalizationData, two: str) -> \
-            plugin.CommandFinalizationData:
+    def cmdfinalization_hook_too_many_parameters(
+        self, one: plugin.CommandFinalizationData, two: str
+    ) -> plugin.CommandFinalizationData:
         """A command finalization hook with too many parameters."""
         return one
 
@@ -267,14 +263,15 @@ class Plugin:
 
 class PluggedApp(Plugin, cmd2.Cmd):
     """A sample app with a plugin mixed in"""
-    def __init__(self, *args, **kwargs):
+
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    def do_say(self, statement):
+    def do_say(self, statement) -> None:
         """Repeat back the arguments"""
         self.poutput(statement)
 
-    def do_skip_postcmd_hooks(self, _):
+    def do_skip_postcmd_hooks(self, _) -> NoReturn:
         self.poutput("In do_skip_postcmd_hooks")
         raise exceptions.SkipPostcommandHooks
 
@@ -282,26 +279,29 @@ class PluggedApp(Plugin, cmd2.Cmd):
     parser.add_argument("my_arg", help="some help text")
 
     @with_argparser(parser)
-    def do_argparse_cmd(self, namespace: argparse.Namespace):
+    def do_argparse_cmd(self, namespace: argparse.Namespace) -> None:
         """Repeat back the arguments"""
         self.poutput(namespace.cmd2_statement.get())
 
+
 ###
 #
 # test pre and postloop hooks
 #
 ###
-def test_register_preloop_hook_too_many_parameters():
+def test_register_preloop_hook_too_many_parameters() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_preloop_hook(app.prepost_hook_too_many_parameters)
 
-def test_register_preloop_hook_with_return_annotation():
+
+def test_register_preloop_hook_with_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_preloop_hook(app.prepost_hook_with_wrong_return_annotation)
 
-def test_preloop_hook(capsys):
+
+def test_preloop_hook(capsys) -> None:
     # Need to patch sys.argv so cmd2 doesn't think it was called with arguments equal to the py.test args
     testargs = ["prog", "say hello", 'quit']
 
@@ -314,7 +314,8 @@ def test_preloop_hook(capsys):
     assert out == 'one\nhello\n'
     assert not err
 
-def test_preloop_hooks(capsys):
+
+def test_preloop_hooks(capsys) -> None:
     # Need to patch sys.argv so cmd2 doesn't think it was called with arguments equal to the py.test args
     testargs = ["prog", "say hello", 'quit']
 
@@ -328,17 +329,20 @@ def test_preloop_hooks(capsys):
     assert out == 'one\ntwo\nhello\n'
     assert not err
 
-def test_register_postloop_hook_too_many_parameters():
+
+def test_register_postloop_hook_too_many_parameters() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postloop_hook(app.prepost_hook_too_many_parameters)
 
-def test_register_postloop_hook_with_wrong_return_annotation():
+
+def test_register_postloop_hook_with_wrong_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postloop_hook(app.prepost_hook_with_wrong_return_annotation)
 
-def test_postloop_hook(capsys):
+
+def test_postloop_hook(capsys) -> None:
     # Need to patch sys.argv so cmd2 doesn't think it was called with arguments equal to the py.test args
     testargs = ["prog", "say hello", 'quit']
 
@@ -351,7 +355,8 @@ def test_postloop_hook(capsys):
     assert out == 'hello\none\n'
     assert not err
 
-def test_postloop_hooks(capsys):
+
+def test_postloop_hooks(capsys) -> None:
     # Need to patch sys.argv so cmd2 doesn't think it was called with arguments equal to the py.test args
     testargs = ["prog", "say hello", 'quit']
 
@@ -365,12 +370,13 @@ def test_postloop_hooks(capsys):
     assert out == 'hello\none\ntwo\n'
     assert not err
 
+
 ###
 #
 # test preparse hook
 #
 ###
-def test_preparse(capsys):
+def test_preparse(capsys) -> None:
     app = PluggedApp()
     app.register_postparsing_hook(app.preparse)
     app.onecmd_plus_hooks('say hello')
@@ -379,37 +385,43 @@ def test_preparse(capsys):
     assert not err
     assert app.called_preparse == 1
 
+
 ###
 #
 # test postparsing hooks
 #
 ###
-def test_postparsing_hook_too_many_parameters():
+def test_postparsing_hook_too_many_parameters() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postparsing_hook(app.postparse_hook_too_many_parameters)
 
-def test_postparsing_hook_undeclared_parameter_annotation():
+
+def test_postparsing_hook_undeclared_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postparsing_hook(app.postparse_hook_undeclared_parameter_annotation)
 
-def test_postparsing_hook_wrong_parameter_annotation():
+
+def test_postparsing_hook_wrong_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postparsing_hook(app.postparse_hook_wrong_parameter_annotation)
 
-def test_postparsing_hook_undeclared_return_annotation():
+
+def test_postparsing_hook_undeclared_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postparsing_hook(app.postparse_hook_undeclared_return_annotation)
 
-def test_postparsing_hook_wrong_return_annotation():
+
+def test_postparsing_hook_wrong_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postparsing_hook(app.postparse_hook_wrong_return_annotation)
 
-def test_postparsing_hook(capsys):
+
+def test_postparsing_hook(capsys) -> None:
     app = PluggedApp()
     app.onecmd_plus_hooks('say hello')
     out, err = capsys.readouterr()
@@ -434,7 +446,8 @@ def test_postparsing_hook(capsys):
     assert not err
     assert app.called_postparsing == 2
 
-def test_postparsing_hook_stop_first(capsys):
+
+def test_postparsing_hook_stop_first(capsys) -> None:
     app = PluggedApp()
     app.register_postparsing_hook(app.postparse_hook_stop)
     stop = app.onecmd_plus_hooks('say hello')
@@ -448,7 +461,8 @@ def test_postparsing_hook_stop_first(capsys):
     assert app.called_postparsing == 1
     assert stop
 
-def test_postparsing_hook_stop_second(capsys):
+
+def test_postparsing_hook_stop_second(capsys) -> None:
     app = PluggedApp()
     app.register_postparsing_hook(app.postparse_hook)
     stop = app.onecmd_plus_hooks('say hello')
@@ -469,7 +483,8 @@ def test_postparsing_hook_stop_second(capsys):
     assert app.called_postparsing == 2
     assert stop
 
-def test_postparsing_hook_emptystatement_first(capsys):
+
+def test_postparsing_hook_emptystatement_first(capsys) -> None:
     app = PluggedApp()
     app.register_postparsing_hook(app.postparse_hook_emptystatement)
     stop = app.onecmd_plus_hooks('say hello')
@@ -489,7 +504,8 @@ def test_postparsing_hook_emptystatement_first(capsys):
     assert not err
     assert app.called_postparsing == 1
 
-def test_postparsing_hook_emptystatement_second(capsys):
+
+def test_postparsing_hook_emptystatement_second(capsys) -> None:
     app = PluggedApp()
     app.register_postparsing_hook(app.postparse_hook)
     stop = app.onecmd_plus_hooks('say hello')
@@ -519,7 +535,8 @@ def test_postparsing_hook_emptystatement_second(capsys):
     assert not err
     assert app.called_postparsing == 2
 
-def test_postparsing_hook_exception(capsys):
+
+def test_postparsing_hook_exception(capsys) -> None:
     app = PluggedApp()
     app.register_postparsing_hook(app.postparse_hook_exception)
     stop = app.onecmd_plus_hooks('say hello')
@@ -539,39 +556,45 @@ def test_postparsing_hook_exception(capsys):
     assert err
     assert app.called_postparsing == 1
 
+
 ###
 #
 # test precmd hooks
 #
 #####
-def test_register_precmd_hook_parameter_count():
+def test_register_precmd_hook_parameter_count() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_precmd_hook(app.precmd_hook_not_enough_parameters)
     with pytest.raises(TypeError):
         app.register_precmd_hook(app.precmd_hook_too_many_parameters)
 
-def test_register_precmd_hook_no_parameter_annotation():
+
+def test_register_precmd_hook_no_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_precmd_hook(app.precmd_hook_no_parameter_annotation)
 
-def test_register_precmd_hook_wrong_parameter_annotation():
+
+def test_register_precmd_hook_wrong_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_precmd_hook(app.precmd_hook_wrong_parameter_annotation)
 
-def test_register_precmd_hook_no_return_annotation():
+
+def test_register_precmd_hook_no_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_precmd_hook(app.precmd_hook_no_return_annotation)
 
-def test_register_precmd_hook_wrong_return_annotation():
+
+def test_register_precmd_hook_wrong_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_precmd_hook(app.precmd_hook_wrong_return_annotation)
 
-def test_precmd_hook(capsys):
+
+def test_precmd_hook(capsys) -> None:
     app = PluggedApp()
     app.onecmd_plus_hooks('say hello')
     out, err = capsys.readouterr()
@@ -599,7 +622,8 @@ def test_precmd_hook(capsys):
     # with two hooks registered, we should get precmd() and both hooks
     assert app.called_precmd == 3
 
-def test_precmd_hook_emptystatement_first(capsys):
+
+def test_precmd_hook_emptystatement_first(capsys) -> None:
     app = PluggedApp()
     app.register_precmd_hook(app.precmd_hook_emptystatement)
     stop = app.onecmd_plus_hooks('say hello')
@@ -624,7 +648,8 @@ def test_precmd_hook_emptystatement_first(capsys):
     # called
     assert app.called_precmd == 1
 
-def test_precmd_hook_emptystatement_second(capsys):
+
+def test_precmd_hook_emptystatement_second(capsys) -> None:
     app = PluggedApp()
     app.register_precmd_hook(app.precmd_hook)
     stop = app.onecmd_plus_hooks('say hello')
@@ -660,39 +685,45 @@ def test_precmd_hook_emptystatement_second(capsys):
     # if a registered hook throws an exception, precmd() is never called
     assert app.called_precmd == 2
 
+
 ###
 #
 # test postcmd hooks
 #
 ####
-def test_register_postcmd_hook_parameter_count():
+def test_register_postcmd_hook_parameter_count() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postcmd_hook(app.postcmd_hook_not_enough_parameters)
     with pytest.raises(TypeError):
         app.register_postcmd_hook(app.postcmd_hook_too_many_parameters)
 
-def test_register_postcmd_hook_no_parameter_annotation():
+
+def test_register_postcmd_hook_no_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postcmd_hook(app.postcmd_hook_no_parameter_annotation)
 
-def test_register_postcmd_hook_wrong_parameter_annotation():
+
+def test_register_postcmd_hook_wrong_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postcmd_hook(app.postcmd_hook_wrong_parameter_annotation)
 
-def test_register_postcmd_hook_no_return_annotation():
+
+def test_register_postcmd_hook_no_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postcmd_hook(app.postcmd_hook_no_return_annotation)
 
-def test_register_postcmd_hook_wrong_return_annotation():
+
+def test_register_postcmd_hook_wrong_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_postcmd_hook(app.postcmd_hook_wrong_return_annotation)
 
-def test_postcmd(capsys):
+
+def test_postcmd(capsys) -> None:
     app = PluggedApp()
     app.onecmd_plus_hooks('say hello')
     out, err = capsys.readouterr()
@@ -720,7 +751,8 @@ def test_postcmd(capsys):
     # with two hooks registered, we should get precmd() and both hooks
     assert app.called_postcmd == 3
 
-def test_postcmd_exception_first(capsys):
+
+def test_postcmd_exception_first(capsys) -> None:
     app = PluggedApp()
     app.register_postcmd_hook(app.postcmd_hook_exception)
     stop = app.onecmd_plus_hooks('say hello')
@@ -746,7 +778,8 @@ def test_postcmd_exception_first(capsys):
     # called
     assert app.called_postcmd == 1
 
-def test_postcmd_exception_second(capsys):
+
+def test_postcmd_exception_second(capsys) -> None:
     app = PluggedApp()
     app.register_postcmd_hook(app.postcmd_hook)
     stop = app.onecmd_plus_hooks('say hello')
@@ -771,39 +804,45 @@ def test_postcmd_exception_second(capsys):
     # the exception
     assert app.called_postcmd == 2
 
+
 ##
 #
 # command finalization
 #
 ###
-def test_register_cmdfinalization_hook_parameter_count():
+def test_register_cmdfinalization_hook_parameter_count() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_cmdfinalization_hook(app.cmdfinalization_hook_not_enough_parameters)
     with pytest.raises(TypeError):
         app.register_cmdfinalization_hook(app.cmdfinalization_hook_too_many_parameters)
 
-def test_register_cmdfinalization_hook_no_parameter_annotation():
+
+def test_register_cmdfinalization_hook_no_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_cmdfinalization_hook(app.cmdfinalization_hook_no_parameter_annotation)
 
-def test_register_cmdfinalization_hook_wrong_parameter_annotation():
+
+def test_register_cmdfinalization_hook_wrong_parameter_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_cmdfinalization_hook(app.cmdfinalization_hook_wrong_parameter_annotation)
 
-def test_register_cmdfinalization_hook_no_return_annotation():
+
+def test_register_cmdfinalization_hook_no_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_cmdfinalization_hook(app.cmdfinalization_hook_no_return_annotation)
 
-def test_register_cmdfinalization_hook_wrong_return_annotation():
+
+def test_register_cmdfinalization_hook_wrong_return_annotation() -> None:
     app = PluggedApp()
     with pytest.raises(TypeError):
         app.register_cmdfinalization_hook(app.cmdfinalization_hook_wrong_return_annotation)
 
-def test_cmdfinalization(capsys):
+
+def test_cmdfinalization(capsys) -> None:
     app = PluggedApp()
     app.onecmd_plus_hooks('say hello')
     out, err = capsys.readouterr()
@@ -827,7 +866,8 @@ def test_cmdfinalization(capsys):
     assert not err
     assert app.called_cmdfinalization == 2
 
-def test_cmdfinalization_stop_first(capsys):
+
+def test_cmdfinalization_stop_first(capsys) -> None:
     app = PluggedApp()
     app.register_cmdfinalization_hook(app.cmdfinalization_hook_stop)
     app.register_cmdfinalization_hook(app.cmdfinalization_hook)
@@ -838,7 +878,8 @@ def test_cmdfinalization_stop_first(capsys):
     assert app.called_cmdfinalization == 2
     assert stop
 
-def test_cmdfinalization_stop_second(capsys):
+
+def test_cmdfinalization_stop_second(capsys) -> None:
     app = PluggedApp()
     app.register_cmdfinalization_hook(app.cmdfinalization_hook)
     app.register_cmdfinalization_hook(app.cmdfinalization_hook_stop)
@@ -849,7 +890,8 @@ def test_cmdfinalization_stop_second(capsys):
     assert app.called_cmdfinalization == 2
     assert stop
 
-def test_cmdfinalization_hook_exception(capsys):
+
+def test_cmdfinalization_hook_exception(capsys) -> None:
     app = PluggedApp()
     app.register_cmdfinalization_hook(app.cmdfinalization_hook_exception)
     stop = app.onecmd_plus_hooks('say hello')
@@ -869,14 +911,17 @@ def test_cmdfinalization_hook_exception(capsys):
     assert err
     assert app.called_cmdfinalization == 1
 
-def test_cmdfinalization_hook_system_exit(capsys):
+
+def test_cmdfinalization_hook_system_exit() -> None:
     app = PluggedApp()
     app.register_cmdfinalization_hook(app.cmdfinalization_hook_system_exit)
     stop = app.onecmd_plus_hooks('say hello')
     assert stop
     assert app.called_cmdfinalization == 1
+    assert app.exit_code == 5
 
-def test_cmdfinalization_hook_keyboard_interrupt(capsys):
+
+def test_cmdfinalization_hook_keyboard_interrupt() -> None:
     app = PluggedApp()
     app.register_cmdfinalization_hook(app.cmdfinalization_hook_keyboard_interrupt)
 
@@ -898,7 +943,18 @@ def test_cmdfinalization_hook_keyboard_interrupt(capsys):
     assert stop
     assert app.called_cmdfinalization == 1
 
-def test_skip_postcmd_hooks(capsys):
+
+def test_cmdfinalization_hook_passthrough_exception() -> None:
+    app = PluggedApp()
+    app.register_cmdfinalization_hook(app.cmdfinalization_hook_passthrough_exception)
+
+    expected_err = "Pass me up"
+    with pytest.raises(OSError, match=expected_err):
+        app.onecmd_plus_hooks('say hello')
+    assert app.called_cmdfinalization == 1
+
+
+def test_skip_postcmd_hooks(capsys) -> None:
     app = PluggedApp()
     app.register_postcmd_hook(app.postcmd_hook)
     app.register_cmdfinalization_hook(app.cmdfinalization_hook)
@@ -910,9 +966,9 @@ def test_skip_postcmd_hooks(capsys):
     assert app.called_postcmd == 0
     assert app.called_cmdfinalization == 1
 
-def test_cmd2_argparse_exception(capsys):
-    """
-    Verify Cmd2ArgparseErrors raised after calling a command prevent postcmd events from
+
+def test_cmd2_argparse_exception(capsys) -> None:
+    """Verify Cmd2ArgparseErrors raised after calling a command prevent postcmd events from
     running but do not affect cmdfinalization events
     """
     app = PluggedApp()
